import typing

GenericType = typing.TypeVar("GenericType")

def connect_sockets(input, output):
    """ """

    ...

def find_base_socket_type(socket):
    """ """

    ...

def find_node_input(node, name):
    """ """

    ...

def find_node_input(node, name):
    """ """

    ...
